Level 7: Custom jinja filters, tests and globals on cli
================================================================================

We will test this on '-pd' cli option

.. code-block:: bash

   $ moban -td my-templates/ -t filter.jj2 -pd custom-jj2-plugin

